@@ -1,27 +1,28 @@
-# Copyrights 2007-2008 by Mark Overmeer.
+# Copyrights 2009 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.05.
+# Pod stripped from pm file by OODoc 1.06.
 use warnings;
 use strict;
 
 package XML::Compile::SOAP12;
 use vars '$VERSION';
-$VERSION = '0.78';
+$VERSION = '2.00';
 
 use base 'XML::Compile::SOAP';
 
-use Log::Report 'xml-compile-soap', syntax => 'SHORT';
+use Log::Report 'xml-compile-soap12', syntax => 'SHORT';
 
-use XML::Compile::Util       qw/SCHEMA2001/;
-use XML::Compile::SOAP::Util qw/:soap12/;
+use XML::Compile::Util;
+use XML::Compile::SOAP::Util;
+use XML::Compile::SOAP12::Util;
 
 my %roles =
  ( NEXT     => SOAP12NEXT
  , NONE     => SOAP12NONE
  , ULTIMATE => SOAP12ULTIMATE
  );
-my %rroles = reverse %roles;
+my %rev_roles = reverse %roles;
 
 XML::Compile->addSchemaDirs(__FILE__);
 XML::Compile->knownNamespace
@@ -38,21 +39,14 @@ sub new($@)
 
 sub init($)
 {   my ($self, $args) = @_;
-    $args->{version}               ||= 'SOAP12';
-    $args->{schema_ns}             ||= SCHEMA2001;
-    my $env = $args->{envelope_ns} ||= SOAP12ENV;
-    my $enc = $args->{encoding_ns} ||= SOAP12ENC;
+    $args->{version}     = 'SOAP12';
     $self->SUPER::init($args);
 
-    my $rpc = $self->{rpc} = $args->{rpc} || SOAP12RPC;
-
-    $self->schemas->importDefinitions( [$env, $enc, $rpc] );
+    $self->schemas->importDefinitions( [SOAP12ENC, SOAP12ENV, SOAP12RPC] );
     $self;
 }
 
 
-sub rpcNS() {shift->{rpc}}
-
 sub sender($)
 {   my ($self, $args) = @_;
 
@@ -64,6 +58,6 @@ sub sender($)
 
 sub roleURI($) { $roles{$_[1]} || $_[1] }
 
-sub roleAbbreviation($) { $rroles{$_[1]} || $_[1] }
+sub roleAbbreviation($) { $rev_roles{$_[1]} || $_[1] }
 
 1;
