@@ -1,7 +1,7 @@
-# Copyrights 2007-2022 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2009 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.03.
+# Pod stripped from pm file by OODoc 1.06.
 use warnings;
 use strict;
 
@@ -10,11 +10,12 @@ use lib '../XMLCompile/lib', '../LogReport/lib', '../XMLTester/lib';
 
 package TestTools;
 use vars '$VERSION';
-$VERSION = '3.28';
+$VERSION = '2.00';
 
 use base 'Exporter';
 
 use Test::More;
+use Test::Deep   qw/cmp_deeply/;
 
 use Log::Report  qw/try/;
 use Data::Dumper qw/Dumper/;
@@ -66,7 +67,7 @@ sub reader_dump($$$)
     my $h = $r->($xml);
     ok(defined $h, 'processed via dumped source');
  
-    is_deeply($h, $hash, "dump and direct trees");
+    cmp_deeply($h, $hash, "dump and direct trees");
 }
 
 
